EN_addnode

Function EN_addnode 

pub unsafe extern "C" fn EN_addnode(
    ph: EN_Project,
    id: *const c_char,
    nodeType: c_int,
    out_index: *mut c_int,
) -> c_int
@brief Adds a new node to a project. @param ph an EPANET project handle. @param id the ID name of the node to be added. @param nodeType the type of node being added (see @ref EN_NodeType) @param[out] out_index the index of the newly added node @return an error code.

When a new node is created all of its properties (see @ref EN_NodeProperty) are set to 0.