EN_getaveragepatternvalue

Function EN_getaveragepatternvalue 

pub unsafe extern "C" fn EN_getaveragepatternvalue(
    ph: EN_Project,
    index: c_int,
    out_value: *mut f64,
) -> c_int
@brief Retrieves the average of all pattern factors in a time pattern. @param ph an EPANET project handle. @param index a time pattern index (starting from 1). @param[out] out_value The average of all of the time pattern’s factors. @return an error code.