EN_getdemandpattern

Function EN_getdemandpattern 

pub unsafe extern "C" fn EN_getdemandpattern(
    ph: EN_Project,
    nodeIndex: c_int,
    demandIndex: c_int,
    out_patIndex: *mut c_int,
) -> c_int
@brief Retrieves the index of a time pattern assigned to one of a node’s demand categories. @param ph an EPANET project handle. @param nodeIndex the node’s index (starting from 1). @param demandIndex the index of a demand category for the node (starting from 1). @param[out] out_patIndex the index of the category’s time pattern. @return an error code.

A returned pattern index of 0 indicates that no time pattern has been assigned to the demand category.