EN_getnodevalues

Function EN_getnodevalues 

pub unsafe extern "C" fn EN_getnodevalues(
    ph: EN_Project,
    property: c_int,
    out_values: *mut f64,
) -> c_int
@brief Retrieves an array of property values for all nodes. @param ph an EPANET project handle. @param property the property to retrieve (see @ref EN_NodeProperty). @param[out] out_values an array of values for all nodes. @return an error code.

Values are returned in units that depend on the units used for flow rate (see @ref Units).