EN_getpatternlen

Function EN_getpatternlen 

pub unsafe extern "C" fn EN_getpatternlen(
    ph: EN_Project,
    index: c_int,
    out_len: *mut c_int,
) -> c_int
@brief Retrieves the number of time periods in a time pattern. @param ph an EPANET project handle. @param index a time pattern index (starting from 1). @param[out] out_len the number of time periods in the pattern. @return an error code.