EN_getpatternvalue

Function EN_getpatternvalue 

pub unsafe extern "C" fn EN_getpatternvalue(
    ph: EN_Project,
    index: c_int,
    period: c_int,
    out_value: *mut f64,
) -> c_int
@brief Retrieves a time pattern’s factor for a given time period. @param ph an EPANET project handle. @param index a time pattern index (starting from 1). @param period a time period in the pattern (starting from 1). @param[out] out_value the pattern factor for the given time period. @return an error code.