EN_loadpatternfile

Function EN_loadpatternfile 

pub unsafe extern "C" fn EN_loadpatternfile(
    ph: EN_Project,
    filename: *const c_char,
    id: *const c_char,
) -> c_int
@brief Loads time patterns from a file into a project under a specific pattern ID. @param ph an EPANET project handle. @param filename the name of the file containing pattern data. @param id the ID name of the new pattern to load. @return an error code.