EN_setdemandpattern

Function EN_setdemandpattern 

pub unsafe extern "C" fn EN_setdemandpattern(
    ph: EN_Project,
    nodeIndex: c_int,
    demandIndex: c_int,
    patIndex: c_int,
) -> c_int
@brief Sets the index of a time pattern used for one of a node’s demand categories. @param ph an EPANET project handle. @param nodeIndex a node’s index (starting from 1). @param demandIndex the index of one of the node’s demand categories (starting from 1). @param patIndex the index of the time pattern assigned to the category. @return an error code.

Specifying a pattern index of 0 indicates that no time pattern is assigned to the demand category.