EN_setpattern

Function EN_setpattern 

pub unsafe extern "C" fn EN_setpattern(
    ph: EN_Project,
    index: c_int,
    values: *mut f64,
    len: c_int,
) -> c_int
@brief Sets the pattern factors for a given time pattern. @param ph an EPANET project handle. @param index a time pattern index (starting from 1). @param values an array of new pattern factor values. @param len the number of factor values supplied. @return an error code.

values is a zero-based array that contains len elements.

Use this function to redefine (and resize) a time pattern all at once; use @ref EN_setpatternvalue to revise pattern factors one at a time.