EN_setpatternvalue

Function EN_setpatternvalue 

pub unsafe extern "C" fn EN_setpatternvalue(
    ph: EN_Project,
    index: c_int,
    period: c_int,
    value: f64,
) -> c_int
@brief Sets a time pattern’s factor for a given time period. @param ph an EPANET project handle. @param index a time pattern index (starting from 1). @param period a time period in the pattern (starting from 1). @param value the new value of the pattern factor for the given time period. @return an error code.