EN_setreportcallbackuserdata

Function EN_setreportcallbackuserdata 

pub unsafe extern "C" fn EN_setreportcallbackuserdata(
    ph: EN_Project,
    userData: *mut c_void,
) -> c_int
@brief Sets a pointer to a client-side data object @param ph an EPANET project handle. @param userData a pointer to a client-side data object. @return an error code.

The data pointer supplied by this function is passed into the callback function declared in ::EN_setreportcallback that replaces a project’s report file as the destination for output written with ::EN_writeline.