EN_ActionCodeType

Type Alias EN_ActionCodeType 

pub type EN_ActionCodeType = c_uint;
Deletion action codes ** These codes are used in @ref EN_deletenode and @ref EN_deletelink to indicate what action should be taken if the node or link being deleted appears in any simple or rule-based controls or if a deleted node has any links connected to it. */