EN_MixingModel

Type Alias EN_MixingModel 

pub type EN_MixingModel = c_uint;
Tank mixing models ** These are the different types of models that describe water quality mixing in storage tanks. The choice of model is accessed with the EN_MIXMODEL property of a Tank node using @ref EN_getnodevalue and @ref EN_setnodevalue. */