EN_SourceType

Type Alias EN_SourceType 

pub type EN_SourceType = c_uint;
Water quality source types ** These are the different types of external water quality sources that can be assigned to a node’s EN_SOURCETYPE property as used by @ref EN_getnodevalue and @ref EN_setnodevalue. */