EN_StatisticType

Type Alias EN_StatisticType 

pub type EN_StatisticType = c_uint;
Reporting statistic choices ** These options determine what kind of statistical post-processing should be done on the time series of simulation results before they are reported using @ref EN_report or saved to the project’s binary output file. These options are used in the @ref EN_gettimeparam and @ref EN_settimeparam functions when EN_STATISTIC is the time parameter being set or retrieved. */