pub unsafe extern "C" fn EN_addpattern(
ph: EN_Project,
id: *const c_char,
) -> c_intExpand description
@brief Adds a new time pattern to a project. @param ph an EPANET project handle. @param id the ID name of the pattern to add. @return an error code.
The new pattern contains a single time period whose factor is 1.0.