pub type EN_AnalysisStatistic = c_uint;Expand description
Analysis convergence statistics ** These statistics report the convergence criteria for the most current hydraulic analysis and the cumulative water quality mass balance error at the current simulation time. They can be retrieved with @ref EN_getstatistic. */