pub type EN_DemandModel = c_uint;Expand description
Demand models ** These choices for modeling consumer demands are used with @ref EN_getdemandmodel and @ref EN_setdemandmodel.
A demand driven analysis requires that a junction’s full demand be supplied in each time period independent of how much pressure is available. A pressure driven analysis makes demand be a power function of pressure, up to the point where the full demand is met. */