pub type EN_PumpStateType = c_uint;Expand description
Pump states
**
One of these codes is returned when @ref EN_getlinkvalue is used to retrieve a pump’s
current operating state (EN_PUMP_STATE). EN_PUMP_XHEAD indicates that the pump has been
shut down because it is being asked to deliver more than its shutoff head. EN_PUMP_XFLOW
indicates that the pump is being asked to deliver more than its maximum flow.
*/