pub type EN_TimeParameter = c_uint;Expand description
Time parameters ** These time-related options are used with @ref EN_gettimeparam and@ref EN_settimeparam. All times are expressed in seconds The parameters marked as read only are computed values that can only be retrieved. */